@@ -167,6 +167,10 @@ class HttpRunner(object):
         resp_obj = ResponseObject(resp)
         step.variables["response"] = resp_obj
 
+        if USE_ALLURE:
+                import json
+                allure.attach(json.dumps(parsed_request_dict), "request", allure.attachment_type.JSON)
+
         # teardown hooks
         if step.teardown_hooks:
             self.__call_hooks(step.teardown_hooks, step.variables, "teardown request")
